## ----packages------------------------------------------------------------------------------------
library(surveillance)

## ----data----------------------------------------------------------------------------------------
load("data/data_BE.RData", verbose = TRUE)

## ----fit1----------------------------------------------------------------------------------------
# first define a subset of the data to which to fit (will be used in all model
# fits to ensure comparability of AIC values):
subset_fit <- 6:(nrow(noroBE@observed) - 52)
# we are leaving out the last year and the first 5 observations
# the latter serves to ensure comparability models with 
# higher-order lags, see below.

##################################################################
# Model 1:
# control list:
ctrl1 <- list(end = list(f = addSeason2formula(~1, S = 1)), # seasonality in end
              # S = 1 means one pair of sine / cosine waves is included
              ar = list(f = ~ 1), # no seasonality in ar
              family = "NegBin1", # negative binomial (rather than Poisson)
              subset = subset_fit)
# fit model
fit1 <- hhh4(noroBE, ctrl1)

## ----function_pr---------------------------------------------------------------------------------
# helper function to compute Pearson residuals. Just provide the model fit 
# as the only argument.
# returns a matrix with Pearson residuals in the different strata (columns)
# and time points (rows)
# note: this is a bit more complicated as it also handles an extended version
# of the hhh4 class called hhh4lag
pearson_residuals <- function(hhh4Obj){
  # compute raw residuals:
  response_residuals <- residuals(hhh4Obj, type = "response")
  # compute standard deviations:
  if(inherits(hhh4Obj, "hhh4lag")){
    sds <- sqrt(fitted(hhh4Obj) + 
                  fitted(hhh4Obj)^2/hhh4addon:::psi2size.hhh4lag(hhh4Obj))
  }else{
    sds <- sqrt(fitted(hhh4Obj) + 
                  fitted(hhh4Obj)^2/surveillance:::psi2size.hhh4(hhh4Obj))
  }
  # compute Pearson residuals:
  pearson_residuals <- response_residuals/sds
  return(pearson_residuals)
}

## ----Bonus: hhh4addon, fig.height=4--------------------------------------------------------------
## to install hhh4addon:
# install.packages("remotes")
# remotes::install_github("jbracher/hhh4addon", build_vignettes = TRUE)

library(hhh4addon)

