## ----import ECDC data----------------------------------------------------------------------------
ecdc_long <- read.csv(
    file = "data/ECDC_surveillance_data_IMD.csv.gz",  # R can read compressed files
    na.strings = "-")  # always important to know how NA's are encoded!
head(ecdc_long, 10)

## exclude aggregate counts
ecdc_long <- subset(ecdc_long, !startsWith(RegionName, "EU"))

## reshape from long to wide format of multivariate time series
ecdc <- reshape(ecdc_long[c("Time", "RegionCode", "NumValue")],
                direction = "wide", idvar = "Time", timevar = "RegionCode")
names(ecdc) <- sub("NumValue.", "", names(ecdc), fixed = TRUE)
row.names(ecdc) <- ecdc$Time; ecdc$Time <- NULL
head(ecdc)

## restrict to countries with complete data (KISS)
ecdc <- ecdc[, colSums(is.na(ecdc)) == 0]
tail(ecdc)

## ----import population data----------------------------------------------------------------------
popdata <- read.csv("data/Eurostat_population_2018.csv")
head(popdata, 3)
stopifnot(colnames(ecdc) %in% popdata$geo)
pop <- setNames(popdata$OBS_VALUE, popdata$geo)[colnames(ecdc)]
pop

## ----load map------------------------------------------------------------------------------------
load("data/map.RData", verbose = TRUE)

## ----plot map------------------------------------------------------------------------------------
library("sp")
par(mar = c(0,0,0,0)) # no margin
plot(map)

## ----start year/index----------------------------------------------------------------------------
(start <- as.numeric(strsplit(rownames(ecdc), "-")[[1]]))

## ----create sts, results = "hide"----------------------------------------------------------------
library("surveillance")

## See help("sts") and learn about the function arguments:
str(sts)
## Complete the following expression:
## IMD <- sts(....)

## ----print the created sts object----------------------------------------------------------------
IMD

## ----basic methods for sts, include = FALSE------------------------------------------------------
##
## help(sts)  # Section "Methods"
##

## ----plot sts, include = FALSE-------------------------------------------------------------------
##
## help(plot.sts)
##

